# Valabn

Valabn (read *valaban*) is a simple Australian Business Number (ABN) validator.

## Installation

Add this line to your application's Gemfile:

```ruby
gem 'valabn'
```

And then execute:

    $ bundle

Or install it yourself as:

    $ gem install valabn

## Usage

If you just need to check the format of the ABN, just use:

```ruby
Valabn::Utils.validate_format(number) #=> Boolean
```

In order to lookup real ABN, you'll need to get a GUID (`https://abr.business.gov.au/RegisterAgreement.aspx`). Once you've got one initialize the gem like this:

```ruby
require 'valabn'

Valabn::Lookup.configure do |config|
  config.guid = APP_GUID # Your assigned GUID
  config.cache_host = 'localhost' # (optional) The host of the redis server
  config.cache_port = '6379' # (optional) The port of the redis server
end

```

`cache_host` and `cache_port` are optional configuration attributes in order to keep a cache on a redis database. The current cache configuration lives up to two hours.

After that, you invoke

```ruby
Valabn::Lookup.validate(abn) #=> Hash

number = Valabn.new(abn)
number.exists? #=> Boolean
number.exists?(details: true) #=> Hash or false
```

## TODO:

* Allow custom expiration time on the cache.
* Integrate with `Activerecord`/`ActiveModel` as validator.
* Add specs

## Development

After checking out the repo, run `bin/setup` to install dependencies. Then, run `rake spec` to run the tests. You can also run `bin/console` for an interactive prompt that will allow you to experiment.

To install this gem onto your local machine, run `bundle exec rake install`. To release a new version, update the version number in `version.rb`, and then run `bundle exec rake release`, which will create a git tag for the version, push git commits and tags, and push the `.gem` file to [rubygems.org](https://rubygems.org).

## Contributing

Bug reports and pull requests are welcome on GitHub at https://github.com/[USERNAME]/valabn. This project is intended to be a safe, welcoming space for collaboration, and contributors are expected to adhere to the [Contributor Covenant](http://contributor-covenant.org) code of conduct.


## License

The gem is available as open source under the terms of the [MIT License](http://opensource.org/licenses/MIT).

